==> mongodb-src-r3.0.5.tar.gz: mongodb-src-r3.0.5/src/mongo/db/storage/in_memory/in_memory_recovery_unit.h <==
// in_memory_recovery_unit.h

/**
*    Copyright (C) 2014 MongoDB Inc.
*
*    This program is free software: you can redistribute it and/or  modify
*    it under the terms of the GNU Affero General Public License, version 3,
*    as published by the Free Software Foundation.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU Affero General Public License for more details.
*
*    You should have received a copy of the GNU Affero General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*    As a special exception, the copyright holders give permission to link the
*    code of portions of this program with the OpenSSL library under certain
*    conditions as described in each individual source file and distribute
*    linked combinations including the program with the OpenSSL library. You
*    must comply with the GNU Affero General Public License in all respects for
*    all of the code used other than as permitted herein. If you modify file(s)
*    with this exception, you may extend this exception to your version of the
*    file(s), but you are not obligated to do so. If you do not wish to do so,
*    delete this exception statement from your version. If you delete this
*    exception statement from all source files in the program, then also delete
*    it in the license file.
*/

#pragma once

#include <boost/shared_ptr.hpp>
#include <vector>

#include "mongo/db/record_id.h"
#include "mongo/db/storage/recovery_unit.h"

namespace mongo {

    class SortedDataInterface;

    class InMemoryRecoveryUnit : public RecoveryUnit {
    public:
        InMemoryRecoveryUnit() : _depth(0) {}
        virtual ~InMemoryRecoveryUnit();

        virtual void beginUnitOfWork(OperationContext* opCtx);
        virtual void commitUnitOfWork();
        virtual void endUnitOfWork();

        virtual bool awaitCommit() {
            return true;
        }

        virtual void commitAndRestart() {}

        virtual void registerChange(Change* change) {
            _changes.push_back(ChangePtr(change));
        }

        virtual void* writingPtr(void* data, size_t len) {
            invariant(!"don't call writingPtr");
        }

        virtual void setRollbackWritesDisabled() {}

        virtual SnapshotId getSnapshotId() const { return SnapshotId(); }

    private:
        typedef boost::shared_ptr<Change> ChangePtr;
        typedef std::vector<ChangePtr> Changes;

        int _depth;
        Changes _changes;
    };

}

==> mongodb-src-r3.0.14.tar.gz: mongodb-src-r3.0.14/src/mongo/db/storage/in_memory/in_memory_recovery_unit.h <==
// in_memory_recovery_unit.h

/**
*    Copyright (C) 2014 MongoDB Inc.
*
*    This program is free software: you can redistribute it and/or  modify
*    it under the terms of the GNU Affero General Public License, version 3,
*    as published by the Free Software Foundation.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU Affero General Public License for more details.
*
*    You should have received a copy of the GNU Affero General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*    As a special exception, the copyright holders give permission to link the
*    code of portions of this program with the OpenSSL library under certain
*    conditions as described in each individual source file and distribute
*    linked combinations including the program with the OpenSSL library. You
*    must comply with the GNU Affero General Public License in all respects for
*    all of the code used other than as permitted herein. If you modify file(s)
*    with this exception, you may extend this exception to your version of the
*    file(s), but you are not obligated to do so. If you do not wish to do so,
*    delete this exception statement from your version. If you delete this
*    exception statement from all source files in the program, then also delete
*    it in the license file.
*/

#pragma once

#include <boost/shared_ptr.hpp>
#include <vector>

#include "mongo/db/record_id.h"
#include "mongo/db/storage/recovery_unit.h"

namespace mongo {

class SortedDataInterface;

class InMemoryRecoveryUnit : public RecoveryUnit {
public:
    InMemoryRecoveryUnit() : _depth(0) {}
    virtual ~InMemoryRecoveryUnit();

    virtual void beginUnitOfWork(OperationContext* opCtx);
    virtual void commitUnitOfWork();
    virtual void endUnitOfWork();

    virtual bool awaitCommit() {
        return true;
    }

    virtual void commitAndRestart() {}

    virtual void registerChange(Change* change) {
        _changes.push_back(ChangePtr(change));
    }

    virtual void* writingPtr(void* data, size_t len) {
        invariant(!"don't call writingPtr");
    }

    virtual void setRollbackWritesDisabled() {}

    virtual SnapshotId getSnapshotId() const {
        return SnapshotId();
    }

private:
    typedef boost::shared_ptr<Change> ChangePtr;
    typedef std::vector<ChangePtr> Changes;

    int _depth;
    Changes _changes;
};
}
